==> servicecatalog-model-5.10.2-sources.jar: io/fabric8/servicecatalog/api/model/ServiceBindingSpecBuilder.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ServiceBindingSpecBuilder extends io.fabric8.servicecatalog.api.model.ServiceBindingSpecFluentImpl<io.fabric8.servicecatalog.api.model.ServiceBindingSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.servicecatalog.api.model.ServiceBindingSpec,io.fabric8.servicecatalog.api.model.ServiceBindingSpecBuilder>{
  public ServiceBindingSpecBuilder() {
    this(false);
  }
  public ServiceBindingSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ServiceBindingSpec(), validationEnabled);
  }
  public ServiceBindingSpecBuilder(io.fabric8.servicecatalog.api.model.ServiceBindingSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ServiceBindingSpecBuilder(io.fabric8.servicecatalog.api.model.ServiceBindingSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ServiceBindingSpec(), validationEnabled);
  }
  public ServiceBindingSpecBuilder(io.fabric8.servicecatalog.api.model.ServiceBindingSpecFluent<?> fluent,io.fabric8.servicecatalog.api.model.ServiceBindingSpec instance) {
    this(fluent, instance, false);
  }
  public ServiceBindingSpecBuilder(io.fabric8.servicecatalog.api.model.ServiceBindingSpecFluent<?> fluent,io.fabric8.servicecatalog.api.model.ServiceBindingSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withExternalID(instance.getExternalID()); 
    fluent.withInstanceRef(instance.getInstanceRef()); 
    fluent.withParameters(instance.getParameters()); 
    fluent.withParametersFrom(instance.getParametersFrom()); 
    fluent.withSecretName(instance.getSecretName()); 
    fluent.withSecretTransforms(instance.getSecretTransforms()); 
    fluent.withUserInfo(instance.getUserInfo()); 
    this.validationEnabled = validationEnabled; 
  }
  public ServiceBindingSpecBuilder(io.fabric8.servicecatalog.api.model.ServiceBindingSpec instance) {
    this(instance,false);
  }
  public ServiceBindingSpecBuilder(io.fabric8.servicecatalog.api.model.ServiceBindingSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withExternalID(instance.getExternalID()); 
    this.withInstanceRef(instance.getInstanceRef()); 
    this.withParameters(instance.getParameters()); 
    this.withParametersFrom(instance.getParametersFrom()); 
    this.withSecretName(instance.getSecretName()); 
    this.withSecretTransforms(instance.getSecretTransforms()); 
    this.withUserInfo(instance.getUserInfo()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.servicecatalog.api.model.ServiceBindingSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.servicecatalog.api.model.ServiceBindingSpec build() {
    ServiceBindingSpec buildable = new ServiceBindingSpec(fluent.getExternalID(),fluent.getInstanceRef(),fluent.getParameters(),fluent.getParametersFrom(),fluent.getSecretName(),fluent.getSecretTransforms(),fluent.getUserInfo());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ServiceBindingSpecBuilder that = (ServiceBindingSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> servicecatalog-model-6.6.1-sources.jar: io/fabric8/servicecatalog/api/model/ServiceBindingSpecBuilder.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ServiceBindingSpecBuilder extends ServiceBindingSpecFluentImpl<ServiceBindingSpecBuilder> implements VisitableBuilder<ServiceBindingSpec,ServiceBindingSpecBuilder>{
  public ServiceBindingSpecBuilder() {
    this(false);
  }
  public ServiceBindingSpecBuilder(Boolean validationEnabled) {
    this(new ServiceBindingSpec(), validationEnabled);
  }
  public ServiceBindingSpecBuilder(ServiceBindingSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ServiceBindingSpecBuilder(ServiceBindingSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ServiceBindingSpec(), validationEnabled);
  }
  public ServiceBindingSpecBuilder(ServiceBindingSpecFluent<?> fluent,ServiceBindingSpec instance) {
    this(fluent, instance, false);
  }
  public ServiceBindingSpecBuilder(ServiceBindingSpecFluent<?> fluent,ServiceBindingSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withExternalID(instance.getExternalID()); 
    fluent.withInstanceRef(instance.getInstanceRef()); 
    fluent.withParameters(instance.getParameters()); 
    fluent.withParametersFrom(instance.getParametersFrom()); 
    fluent.withSecretName(instance.getSecretName()); 
    fluent.withSecretTransforms(instance.getSecretTransforms()); 
    fluent.withUserInfo(instance.getUserInfo()); 
    this.validationEnabled = validationEnabled; 
  }
  public ServiceBindingSpecBuilder(ServiceBindingSpec instance) {
    this(instance,false);
  }
  public ServiceBindingSpecBuilder(ServiceBindingSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withExternalID(instance.getExternalID()); 
    this.withInstanceRef(instance.getInstanceRef()); 
    this.withParameters(instance.getParameters()); 
    this.withParametersFrom(instance.getParametersFrom()); 
    this.withSecretName(instance.getSecretName()); 
    this.withSecretTransforms(instance.getSecretTransforms()); 
    this.withUserInfo(instance.getUserInfo()); 
    this.validationEnabled = validationEnabled; 
  }
  ServiceBindingSpecFluent<?> fluent;
  Boolean validationEnabled;
  public ServiceBindingSpec build() {
    ServiceBindingSpec buildable = new ServiceBindingSpec(fluent.getExternalID(),fluent.getInstanceRef(),fluent.getParameters(),fluent.getParametersFrom(),fluent.getSecretName(),fluent.getSecretTransforms(),fluent.getUserInfo());
    return buildable;
  }
  
}
